App & Blueprint Objects
=======================

.. module:: flask_jeroboam.jeroboam

.. autoclass:: Jeroboam
   :members:
   :undoc-members:
   :show-inheritance:

.. module:: flask_jeroboam.blueprint

.. autoclass:: Blueprint
   :members:
   :undoc-members:
   :show-inheritance:
